@@ -1,4 +1,4 @@
-/* $Id: internal.h,v 1.2 2001/05/31 21:55:21 skids Exp $
+/* $Id: internal.h,v 1.5 2002/10/20 20:35:49 skids Exp $
 ******************************************************************************
 
    LibGGI internal functions and macros
@@ -74,8 +74,12 @@ int _ggiAddDL(ggi_visual *vis, const char *drv, const char *args,
 	      void *argptr, int type);
 
 /* internal.c */
+int _ggi_countbits(uint32 val);
 int _ggi_mask2shift(uint32 mask);
 void _ggi_build_pixfmt(ggi_pixelformat *pixfmt);
+void _ggi_pixfmtstr(ggi_visual *vis, char* str, int flags);
+/* _ggi_pixfmtstr flags: 1 == break down channels */
+/*                       2 == report alpha as pad */
 int _ggi_match_palette(ggi_color *pal, int pal_len, ggi_color *col);
 ggifunc_setreadframe _ggi_default_setreadframe;
 ggifunc_setwriteframe _ggi_default_setwriteframe;
@@ -113,6 +117,8 @@ void _ggiZapMode(ggi_visual *vis, int zapall);
 ggi_visual *_ggiNewVisual(void);
 void _ggiDestroyVisual(ggi_visual *vis);
 
+enum gg_swartype _ggiGetSwarType(void);
+
 __END_DECLS
 
 
